@@ -156,7 +156,8 @@ static const gnutls_error_entry error_algorithms[] = {
 	       GNUTLS_E_X509_UNSUPPORTED_CRITICAL_EXTENSION, 1),
   ERROR_ENTRY (N_("Key usage violation in certificate has been detected."),
 	       GNUTLS_E_KEY_USAGE_VIOLATION, 1),
-  ERROR_ENTRY (N_("Function was interrupted."), GNUTLS_E_AGAIN, 0),
+  ERROR_ENTRY (N_("Resource temporarily unavailable, try again."),
+	       GNUTLS_E_AGAIN, 0),
   ERROR_ENTRY (N_("Function was interrupted."), GNUTLS_E_INTERRUPTED, 0),
   ERROR_ENTRY (N_("Rehandshake was requested by the peer."),
 	       GNUTLS_E_REHANDSHAKE, 0),
