@@ -654,9 +654,9 @@ _gnutls_recv_finished (gnutls_session_t session)
  */
 static int
 _gnutls_server_find_pk_algos_in_ciphersuites (const opaque *
-					      data, int datalen)
+					      data, unsigned int datalen)
 {
-  int j;
+  unsigned int j;
   gnutls_pk_algorithm_t algo = GNUTLS_PK_NONE, prev_algo = 0;
   gnutls_kx_algorithm_t kx;
   cipher_suite_st cs;
@@ -1705,16 +1705,12 @@ _gnutls_send_client_hello (gnutls_session_t session, int again)
   opaque rnd[GNUTLS_RANDOM_SIZE];
   gnutls_protocol_t hver;
   opaque extdata[MAX_EXT_DATA_LENGTH];
-  int rehandshake = 0;
 
   opaque *SessionID =
     session->internals.resumed_security_parameters.session_id;
   uint8_t session_id_len =
     session->internals.resumed_security_parameters.session_id_size;
 
-  if (session->security_parameters.session_id_size)
-    rehandshake = 1;
-
   if (SessionID == NULL)
     session_id_len = 0;
   else if (session_id_len == 0)
@@ -1738,12 +1734,7 @@ _gnutls_send_client_hello (gnutls_session_t session, int again)
        * version number to the previously established.
        */
       if (SessionID == NULL)
-        {
-          if (rehandshake) /* already negotiated version thus version_max == negotiated version */
-            hver = session->security_parameters.version;
-          else
-            hver = _gnutls_version_max (session);
-        }
+	hver = _gnutls_version_max (session);
       else
 	{			/* we are resuming a session */
 	  hver = session->internals.resumed_security_parameters.version;
@@ -1764,24 +1755,15 @@ _gnutls_send_client_hello (gnutls_session_t session, int again)
        */
       _gnutls_set_adv_version (session, hver);
 
-      if (session->internals.priorities.ssl3_record_version) 
-        {
-          /* Honor the SSL3_RECORD_VERSION option
-           */
-          _gnutls_set_current_version (session, GNUTLS_SSL3);
-        }
-      else
-        {
-          /* Some old implementations do not interoperate if we send a
-           * different version in the record layer.
-           * It seems they prefer to read the record's version
-           * as the one we actually requested.
-           * The proper behaviour is to use the one in the client hello 
-           * handshake packet and ignore the one in the packet's record 
-           * header.
-           */
-          _gnutls_set_current_version (session, hver);
-        }
+      /* Some old implementations do not interoperate if we send a
+       * different version in the record layer.
+       * It seems they prefer to read the record's version
+       * as the one we actually requested.
+       * The proper behaviour is to use the one in the client hello 
+       * handshake packet and ignore the one in the packet's record 
+       * header.
+       */
+      _gnutls_set_current_version (session, hver);
 
       /* In order to know when this session was initiated.
        */
