@@ -27,7 +27,6 @@
  */
 
 #include <gnutls_int.h>
-#include <libtasn1.h>
 #include <gnutls_errors.h>
 #include <gnutls_num.h>
 #include <gnutls_mpi.h>
@@ -120,7 +119,7 @@ wrap_gcry_mpi_get_nbits (bigint_t a)
 static void
 wrap_gcry_mpi_release (bigint_t a)
 {
-  gcry_mpi_release (a);
+  return gcry_mpi_release (a);
 }
 
 #undef _gnutls_mpi_alloc_like
