@@ -28,8 +28,10 @@
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
+#include <sys/select.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <error.h>
 
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
@@ -40,20 +42,12 @@
 /* Gnulib portability files. */
 #include <progname.h>
 #include <version-etc.h>
-
-#include "error.h"
-#include "read-file.h"
-#include "getpass.h"
+#include <read-file.h>
+#include <getpass.h>
 
 #include "common.h"
 #include "cli-gaa.h"
 
-#if defined _WIN32 || defined __WIN32__
-int _win_select (int max_fd, fd_set * rfds, fd_set * wfds, fd_set * efds,
-		 const struct timeval *tv);
-#define select _win_select
-#endif
-
 #define SA struct sockaddr
 #define ERR(err,s) do { if (err==-1) {perror(s);return(1);} } while (0)
 #define MAX_BUF 4096
